@@ -1,4 +1,4 @@
-# Gufw 16.10.0 - http://gufw.org
+# Gufw 18.04.0 - http://gufw.org
 # Copyright (C) 2008-2016 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
@@ -158,7 +158,7 @@ class Backend():
         try:
             if not cfg.read([self.GUFW_CFG]):
                 return ''
-        except:
+        except Exception:
             os.remove(self.GUFW_CFG)
             return ''
         
@@ -291,7 +291,7 @@ class Backend():
         dst = os.path.join(self.GUFW_PATH, profile + '.profile')
         try:
             os.remove(dst)
-        except:
+        except Exception:
             pass
     
     def rename_file_profile(self, old, new):
@@ -303,7 +303,7 @@ class Backend():
         print('renaming '+src+' a '+dst)
         try:
             os.rename(src, dst)
-        except:
+        except Exception:
             pass
     
     def export_profile(self, profile, dst):
@@ -311,7 +311,7 @@ class Backend():
         try:
             shutil.copyfile(src, dst)
             os.chmod(dst, 0o600) # Avoid other users change a profile
-        except:
+        except Exception:
             pass
     
     def refresh_log(self):
@@ -323,7 +323,7 @@ class Backend():
             f = open(self.GUFW_LOG, 'r')
             log = f.readlines()
             f.close()
-        except:
+        except Exception:
             log = ''
         
         new_line = '[' + time.strftime('%x %X') + '] ' + msg
@@ -458,16 +458,14 @@ class Backend():
         return result # cmd | ufw result
     
     def get_net_interfaces(self):
-        cmd_ifaces = ['netstat', '-i']
+        cmd_ifaces = ['ls', '/sys/class/net']
         cmd = self._run_cmd(cmd_ifaces)
         ifaces = cmd.split('\n')
         
-        index = 0
         result = []
         for iface in ifaces:
-            index = index + 1
-            if index > 2 and iface:
-                result.append(iface.split(' ')[0])
+            if iface:
+                result.append(iface)
         
         return result
     
