@@ -1,4 +1,4 @@
-# Gufw 16.10.0 - http://gufw.org
+# Gufw 18.04.0 - http://gufw.org
 # Copyright (C) 2008-2016 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
@@ -169,6 +169,9 @@ class Gufw:
         self.txt_tag_gray   = self.log_txt.create_tag('colored_gray',   foreground=self.GRAY)
         self.txt_tag_black  = self.log_txt.create_tag('colored_black',  foreground=self.BLACK)
         
+        self.btn_report_pause = self.builder.get_object('btnReportPause')
+        self.btn_report_play  = self.builder.get_object('btnReportPlay')
+        
         # Stack init
         stack = Gtk.Stack()
         stack.set_transition_type(Gtk.StackTransitionType.SLIDE_LEFT_RIGHT)
@@ -178,7 +181,7 @@ class Gufw:
         self.viewport_home  = self.builder.get_object('viewport_home')
         self.viewport_home.reparent(vbox_home)
         stack.add_titled(vbox_home, "tutorial", _("Getting started"))
-        stack.child_set_property(vbox_home, "icon-name", "gtk-home") # Set icon
+        stack.child_set_property(vbox_home, "icon-name", "go-home") # Set icon
         # Stack 2 = Rules
         vbox_rules = Gtk.Box()
         self.viewport_rules  = self.builder.get_object('viewport_rules')
@@ -193,6 +196,7 @@ class Gufw:
         vbox_log = Gtk.Box()
         self.viewport_log  = self.builder.get_object('viewport_log')
         self.viewport_log.reparent(vbox_log)
+        # Translators: Noun
         stack.add_titled(vbox_log, "log", _("Log"))
         # Stack Compose
         stack_switcher = Gtk.StackSwitcher()
@@ -230,16 +234,19 @@ class Gufw:
         render_txt = Gtk.CellRendererText()
         
         # Rules
+        # Translators: Number of  rule
         tree_header = Gtk.TreeViewColumn(_("Nº"), render_txt, text=14, foreground=13)
         tree_header.set_resizable(True)
         tree_header.set_sort_column_id(14)
         tree_header.set_sizing(1)
         self.tv_rules.append_column(tree_header)
+        # Translators: Of rule
         tree_header = Gtk.TreeViewColumn(_("Rule"), render_txt, text=0, foreground=13)
         tree_header.set_resizable(True)
         tree_header.set_sort_column_id(0)
         tree_header.set_sizing(1)
         self.tv_rules.append_column(tree_header)
+        # Translators: Of rule
         tree_header = Gtk.TreeViewColumn(_("Name"), render_txt, text=1, foreground=13)
         tree_header.set_resizable(True)
         tree_header.set_sort_column_id(1)
@@ -247,6 +254,7 @@ class Gufw:
         self.tv_rules.append_column(tree_header)
         
         # Listening Report
+        # Translators: Number of  rule
         tree_header = Gtk.TreeViewColumn(_("Nº"), render_txt, text=5, foreground=4)
         tree_header.set_resizable(True)
         tree_header.set_sort_column_id(5)
@@ -289,6 +297,8 @@ class Gufw:
         
         if self.fw.get_status():
             self.print_rules(self.fw.get_rules())
+        
+        self.btn_report_play.hide()
 
     # Disable the context menu
     def context_menu_cb(webview, context_menu, event, hit_test_result, error):
@@ -330,7 +340,7 @@ class Gufw:
         distro = platform.linux_distribution()[0].lower()
         try:
             user = sys.argv[1]
-        except:
+        except Exception:
             self.show_dialog(self.winMain, _("Visit this web (please, copy & paste in your browser):"), url)
             return
         
@@ -465,6 +475,7 @@ class Gufw:
     def on_incoming_changed(self, widget, data=None):
         self.fw.set_policy('incoming', self.NUM2POLICY[self.incoming.get_active()].lower())
         self._set_shield()
+        # Translators: Policy
         self.add_to_log(_("Incoming: ") + self.incoming.get_active_text(), self.POLICY2COLOR[self.fw.get_policy('incoming')])
         self.set_statusbar_msg(_("Incoming policy changed"))
         if self.fw.get_policy('incoming') != self.NUM2POLICY[self.incoming.get_active()].lower():
@@ -481,9 +492,10 @@ class Gufw:
     def on_routed_changed(self, widget, data=None):
         try: # Could be inconsistent between imports and changes of Routed status
             self.fw.set_policy('routed', self.NUM2POLICY[self.routed.get_active()].lower())
-        except:
+        except Exception:
             return
         self._set_shield()
+        # Translators: Routed firewall changed
         self.add_to_log(_("Routed: ") + self.routed.get_active_text(), self.POLICY2COLOR[self.fw.get_policy('routed')])
         self.set_statusbar_msg(_("Routed policy changed"))
         if self.fw.get_policy('routed') != self.NUM2POLICY[self.routed.get_active()].lower():
@@ -517,14 +529,26 @@ class Gufw:
         self.winadd.set_add_from_report(protocol, port, address, app)
         self.winadd.show_win()        
     
+    def on_btnReportPause_clicked(self, widget, data=None):
+        self.btn_report_pause.hide()
+        self.btn_report_play.show()
+        self.listening.set_pause(True)
+    
+    def on_btnReportPlay_clicked(self, widget, data=None):
+        self.btn_report_pause.show()
+        self.btn_report_play.hide()
+        self.listening.set_pause(False)
+    
     def on_switchStatus_active_notify(self, widget, data=None):
         self.fw.set_status(self.switchStatus.get_active())
         self.print_rules(self.fw.get_rules())
         
         if self.fw.get_status():
+            # Translators: About firewall
             self.add_to_log(_("Status: Enabled"), self.GREEN)
             self.set_statusbar_msg(_("Firewall enabled"))
         else:
+            # Translators: About firewall
             self.add_to_log(_("Status: Disabled"), self.RED)
             self.set_statusbar_msg(_("Firewall disabled"))
         
@@ -566,6 +590,7 @@ class Gufw:
                 self.add_to_log(cmd[0])
                 self.set_statusbar_msg(_("Rule(s) deleted"))
             else:
+                # Translators: Error running an ufw command
                 self.add_to_log(_("Error running: ") + cmd[0] + ' > ' + cmd[1].replace('\n', ' | '))
                 self.set_statusbar_msg(_("Error. Review Gufw Log"))
         
@@ -579,7 +604,7 @@ class Gufw:
         while True:
             try:
                 iter_row = model.get_iter(i,)
-            except:
+            except Exception:
                 return i
             i += 1
     
@@ -684,17 +709,29 @@ class Gufw:
         row = 1
         for rule in (rules):
             iter_row = self.rules_model.insert(row)
+            # Translators: ufw string
             translated_rule = rule['ufw_rule'].replace(" ALLOW ",  _(" ALLOW "))
+            # Translators: ufw string
             translated_rule = translated_rule.replace(" DENY ",    _(" DENY "))
+            # Translators: ufw string
             translated_rule = translated_rule.replace(" REJECT ",  _(" REJECT "))
+            # Translators: ufw string
             translated_rule = translated_rule.replace(" LIMIT ",   _(" LIMIT "))
+            # Translators: ufw string
             translated_rule = translated_rule.replace(" OUT ",     _(" OUT "))
+            # Translators: ufw string
             translated_rule = translated_rule.replace(" IN ",      _(" IN "))
+            # Translators: ufw string
             translated_rule = translated_rule.replace(" FWD ",     _(" FWD "))
+            # Translators: ufw string
             translated_rule = translated_rule.replace("Anywhere",  _("Anywhere"))
+            # Translators: ufw string
             translated_rule = translated_rule.replace(" (log) ",     _("(log)"))
+            # Translators: ufw string
             translated_rule = translated_rule.replace(" (log-all) ", _("(log-all)"))
+            # Translators: ufw string
             translated_rule = translated_rule.replace(" (out)",    _(" (out)"))
+            # Translators: ufw string
             translated_rule = translated_rule.replace(" on ",      _(" on "))
             
             self.rules_model.set_value(iter_row, 0,  translated_rule)     # ufw rule
